]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - bih.h
Remove the CONFIG_CD macro, and enable faketracks unconditionally.
[xonotic/darkplaces.git] / bih.h
diff --git a/bih.h b/bih.h
index 810cf9ca9e87ad7e53be86ec7c5c333d6c4a7187..4be1564fda8bcb7f5f34c368e7872439bd0dc335 100644 (file)
--- a/bih.h
+++ b/bih.h
@@ -1,11 +1,13 @@
 
-// This code written in 2010 by Forest Hale (lordhavoc ghdigital com), and placed into public domain.
+// This code written in 2010 by Forest Hale (darkplacesengine gmail com), and placed into public domain.
 
 // Based on information in http://zach.in.tu-clausthal.de/papers/vrst02.html (in particular vrst02_boxtree.pdf)
 
 #ifndef BIH_H
 #define BIH_H
 
+#define BIH_MAXUNORDEREDCHILDREN 8
+
 typedef enum biherror_e
 {
        BIHERROR_OK, // no error, be happy
@@ -17,15 +19,16 @@ typedef enum bih_nodetype_e
 {
        BIH_SPLITX = 0,
        BIH_SPLITY = 1,
-       BIH_SPLITZ = 2
+       BIH_SPLITZ = 2,
+       BIH_UNORDERED = 3,
 }
 bih_nodetype_t;
 
 typedef enum bih_leaftype_e
 {
-       BIH_BRUSH = 3,
-       BIH_COLLISIONTRIANGLE = 4,
-       BIH_RENDERTRIANGLE = 5
+       BIH_BRUSH = 4,
+       BIH_COLLISIONTRIANGLE = 5,
+       BIH_RENDERTRIANGLE = 6
 }
 bih_leaftype_t;
 
@@ -36,12 +39,14 @@ typedef struct bih_node_s
        // TODO: move bounds data to parent node and remove it from leafs?
        float mins[3];
        float maxs[3];
// < 0 is a leaf index (-1-leafindex), >= 0 is another node index (always >= this node's index)
        int front;
        int back;
        // interval of children
        float frontmin; // children[0]
        float backmax; // children[1]
+       // BIH_UNORDERED uses this for a list of leafindex (all >= 0), -1 = end of list
+       int children[BIH_MAXUNORDEREDCHILDREN];
 }
 bih_node_t;
@@ -36,12 +39,14 @@ typedef struct bih_node_s
        float mins[3];
        float maxs[3];
-       // < 0 is a leaf index (-1-leafindex), >= 0 is another node index (always >= this node's index)
+       // node indexes of children (always > this node's index)
        int front;
        int back;